@@ -1,6 +1,6 @@
 from pymatops.pymatops import visualize
 from pymatops.pymatops import randomMatrix
-from pymatops.pymatops import randomMatrixDim
+# from pymatops.pymatops import randomMatrixDim
 from pymatops.pymatops import zeroElements
 from pymatops.pymatops import matSum
 from pymatops.pymatops import evenCheck
